@@ -1,9 +1,12 @@
-package Crypt::Random::Provider::File; 
 use strict;
+use warnings;
+package Crypt::Random::Provider::File; 
 use Carp;
 use Math::Pari qw(pari2num);
 use Fcntl;
 
+our $VERSION = '1.56';
+
 sub _defaultsource { 
     return;
 }
