@@ -1,12 +1,13 @@
-#!/usr/bin/perl -sw
 ##
-## Copyright (c) 1998-2018, Vipul Ved Prakash.  All rights reserved.
+## Copyright (c) 1998-2025, Vipul Ved Prakash.  All rights reserved.
 ## This code is free software; you can redistribute it and/or modify
 ## it under the same terms as Perl itself.
 
-package Crypt::Random::Provider::devurandom; 
+our $VERSION = '1.56';
+
 use strict;
-use lib qw(lib);
+use warnings;
+package Crypt::Random::Provider::devurandom; 
 use Crypt::Random::Provider::File;
 use vars qw(@ISA);
 @ISA = qw(Crypt::Random::Provider::File);
